#!/usr/local/bin/perl5.8.6

# ********************************************************************
# Simple announcement script for SLIMP3 using the CLI             v0.4
#
# Copyright (c) 2003 Felix Mueller (felix.mueller(at)gwendesign.com)
#
# This file might be distributed under the same terms as the
# SLIMP3 server (www.slimdevices.com)
#
# Description:
# checks if one or more player are running
# if yes --> exitcode <> 1
# if no --> exitcode = 0
# Plattform tested:
# - Linux
#
# ********************************************************************

use strict;

use Getopt::Long;
use IO::Socket;

# Parameter
my $szServerIP		= "192.168.80.111";
my $iServerCLIPort	= 9090;
my $szPlayerIPAndPort 	= "";
my $szPlayerName	= "";
my $iPower		= "";
# Internal parameters
my $debug		= 0;	# 0 = off, 1 = on

# Try to open a connection to the SLIMP3 CLI
my $socket = IO::Socket::INET->new(	PeerAddr => $szServerIP,
					PeerPort => $iServerCLIPort,
					Proto => "tcp",
					Type => SOCK_STREAM);
# Check if socket was opened successful
if( !defined( $socket))
{
	print "Cannot connect to $szServerIP:$iServerCLIPort\n";
	exit;
}

# Get the # of players
my $iNumPlayer = sendAndReceive( "player count ?");
$debug && print "iNumPlayer: $iNumPlayer\n";
if( $iNumPlayer eq 0)
{
    exit (0);
}

# Get the player name and checks if player is on
my $iPlayerOn = 0;
for( my $i = 0; $i < $iNumPlayer; $i++)
{
    $szPlayerName = sendAndReceive( "player name $i ?");
    $szPlayerName = encodeChars( $szPlayerName);
    $debug && print "$szPlayerName \n";
    $iPower = sendAndReceive( "$szPlayerName power ?");
    $debug && print "$iPower \n";
    if( $iPower eq 1)
    {
	$iPlayerOn = 1;
    }
}
$debug && print "Playeron: $iPlayerOn \n";
if( $iPlayerOn eq 1)
{
    exit (1);
}

close( $socket);

# ---------------------------------------------
sub sendAndReceive
{
	my $cmd = shift;

	return if( $cmd eq "");

#	$cmd = $szPlayerIP . encodeChars( ":") . $iPlayerPort . " " . $cmd;

	if( $szPlayerIPAndPort ne "")
	{
		$cmd = $szPlayerIPAndPort . " " . $cmd;
	}
	print $socket "$cmd\n";
	my $answer = <$socket>;
	$answer =~ s/$cmd //i;
	$answer =~ s/\n//;

	return $answer;
}

# ---------------------------------------------
sub encodeChars
{
	my $myChars = $_[0];

	my $MetaChars = quotemeta(' ;,/?\|=+)(*&^%$#@!~`:');
	
	$myChars =~ s/([$MetaChars\"\'\x80-\xFF])/"%" . uc( sprintf( "%2.2x", ord($1)))/eg;

	return $myChars;
}

# ---------------------------------------------
